==> gcix-0.0.26-py3-none-any.whl: package/CODE_OF_CONDUCT.md <==
# gcix Project Code of Conduct

We, the community behind the gcix project, are committed to providing a safe, respectful, and inclusive environment for all participants. This Code of Conduct outlines our expectations for behavior within our community, both online and offline, and applies to all contributors, maintainers, users, and participants.

## Expected Behavior

- Treat all individuals with respect, kindness, and empathy.
- Be considerate of differing opinions, experiences, and backgrounds.
- Communicate openly, professionally, and constructively.
- Use welcoming and inclusive language in all interactions.

## Unacceptable Behavior

The following behaviors are considered unacceptable and will not be tolerated within our community:

- Harassment, bullying, discrimination, or offensive comments related to race, gender, sexual orientation, religion, disability, or any other personal characteristic.
- Intimidation, threats, or unwelcome advances of any kind.
- Disruptive or disrespectful comments, trolling, or personal attacks.
- Sharing or promoting explicit or offensive content.
- Any behavior that creates an uncomfortable or unsafe environment for others.

## Reporting Guidelines

If you experience or witness behavior that violates this Code of Conduct, please follow these steps:

1. Notify the individual that their behavior is inappropriate and ask them to stop.
2. If the behavior continues or you are uncomfortable addressing it directly, report the incident to the project maintainers at [gcix@vonessen.eu](mailto:gcix@vonessen.eu).
3. Provide details of the incident, including date, time, individuals involved, and a description of what occurred.

## Consequences

Unacceptable behavior will not be tolerated within our community. Consequences for violating this Code of Conduct may include:

- Verbal or written warnings.
- Temporary or permanent bans from community interactions, events, or online platforms.

## Enforcement

The project maintainers are responsible for enforcing this Code of Conduct. They will review and investigate all reported incidents promptly, treating all reports with discretion and confidentiality.

## Scope

This Code of Conduct applies to all community spaces associated with the gcix project, including but not limited to:

- GitLab repositories, issues, and discussions.
- Online forums, chat rooms, and mailing lists.
- Project-related events and meetups.

## Modifications and Updates

This Code of Conduct may be updated or modified from time to time. Contributors and participants will be informed of any changes, and it is their responsibility to review and adhere to the most recent version.

## Contact Information

If you have any questions, concerns, or need to report an incident, please contact the project maintainers at [email address].

## License

This Code of Conduct is licensed under the [Creative Commons Attribution-ShareAlike 4.0 International License](http://creativecommons.org/licenses/by-sa/4.0/).

---

We value your participation and contribution to the gcix project. Let's work together to create a welcoming and inclusive community for everyone.

==> gcix-0.0.41-py3-none-any.whl: package/CODE_OF_CONDUCT.md <==
# gcix Project Code of Conduct

We, the community behind the gcix project, are committed to providing a safe, respectful, and inclusive environment for all participants. This Code of Conduct outlines our expectations for behavior within our community, both online and offline, and applies to all contributors, maintainers, users, and participants.

## Expected Behavior

- Treat all individuals with respect, kindness, and empathy.
- Be considerate of differing opinions, experiences, and backgrounds.
- Communicate openly, professionally, and constructively.
- Use welcoming and inclusive language in all interactions.

## Unacceptable Behavior

The following behaviors are considered unacceptable and will not be tolerated within our community:

- Harassment, bullying, discrimination, or offensive comments related to race, gender, sexual orientation, religion, disability, or any other personal characteristic.
- Intimidation, threats, or unwelcome advances of any kind.
- Disruptive or disrespectful comments, trolling, or personal attacks.
- Sharing or promoting explicit or offensive content.
- Any behavior that creates an uncomfortable or unsafe environment for others.

## Reporting Guidelines

If you experience or witness behavior that violates this Code of Conduct, please follow these steps:

1. Notify the individual that their behavior is inappropriate and ask them to stop.
2. If the behavior continues or you are uncomfortable addressing it directly, report the incident to the project maintainers at [gcix@gcix.dev](mailto:gcix@gcix.dev).
3. Provide details of the incident, including date, time, individuals involved, and a description of what occurred.

## Consequences

Unacceptable behavior will not be tolerated within our community. Consequences for violating this Code of Conduct may include:

- Verbal or written warnings.
- Temporary or permanent bans from community interactions, events, or online platforms.

## Enforcement

The project maintainers are responsible for enforcing this Code of Conduct. They will review and investigate all reported incidents promptly, treating all reports with discretion and confidentiality.

## Scope

This Code of Conduct applies to all community spaces associated with the gcix project, including but not limited to:

- GitLab repositories, issues, and discussions.
- Online forums, chat rooms, and mailing lists.
- Project-related events and meetups.

## Modifications and Updates

This Code of Conduct may be updated or modified from time to time. Contributors and participants will be informed of any changes, and it is their responsibility to review and adhere to the most recent version.

## Contact Information

If you have any questions, concerns, or need to report an incident, please contact the project maintainers at [email address].

## License

This Code of Conduct is licensed under the [Creative Commons Attribution-ShareAlike 4.0 International License](http://creativecommons.org/licenses/by-sa/4.0/).

---

We value your participation and contribution to the gcix project. Let's work together to create a welcoming and inclusive community for everyone.
